dat = xlsread('pricedata.xls');

dat = 2*dat(361:11260); % removing first and last few observations 
% the movement is in multiple of 0.5 ticks. We multiply by 2 to get integer
% tick movements.
% We are starting from the 361st observation and ending with the 11260th
% observation to remove beginning and end of day effects. Change as you
% find appropriate.


datd = diff(dat);  % this is the price movement series which will be used

[A,D,S] = decompfull(datd);
fid =1; % prints the output to MATLAB command window.
% use fid = fopen('FILENAME.txt','wt'); to print the results to a file.

qvec= [20;100;1500]; % lags for Box-Pierce tests. Change appropriately.
testsize = 0.05; % size of the Box-Pierce tests

y = xlsread('order.xls'); % the important exogenous variable (TransQuantity)
y = log(y(361:11259)); 
% Not taking logs creates problems as some matrices
% will not be appropriately scaled. Taking logs seems to solve the problem.
% NOTE: y will be 1 observation longer that datd (the price movement
% series). Therefore, trim (from below) y one observation more than dat.
% This can be easily done by taking y up to 11259th observation rather than
% 11260th.
y=[y];
% Add/delete exogenous variables as you need. If no exogenous 
% variables are required, type y=[].
[nobsy nexg] = size(y);

LD = (S-A).*D; % large size movements as in Rydberg and Shephard.

%--------------------------------------------------------------------------
% ACTIVITY
% --------
nobs = length(A);
xa = ones(nobs,1);
da = alag(D,2); % lags of D
LDLa = alag(LD,2);
xa = [xa da LDLa]; % endogenous variables. Change appropriately.
[nobs nenda] = size(xa);
pa = 10;  % p can be zero or positive
beta0a = ones(pa+nenda+nexg,1)*0.2; % initial conditions for maximisation

%vnamesa = []; 
% List of variable names. if empty generic variables will be 
% used. If you want to name your variables, use
vnamesa = strvcat('constant','lagD1', 'lagD2', 'LD','lagA1','TranQuant'); 
% changing the list appropriately.
% NOTE: When naming, the order of the variables should be: the ones in x,
% followed by the lags determined by p, followed by the ones in y
% (exogenous).

resA = activity_structure(A,xa,pa,y,beta0a,qvec,testsize);
prtA = activity_print(resA,vnamesa,fid);
%--------------------------------------------------------------------------

% DIRECTION
% ---------
% Exactly the same as ACTIVITY except that including certain lags of D
% create some problems (especially lag 1). I therefore excluded that 
% variable (by setting p=0) and took further lags using the function
% alag(.,.) as below

nobs = length(D);
xd = ones(nobs,1);
LDLd = alag(LD,4);
LDLd = LDLd(:,2:4);
xd = [xd LDLd];
[nobs nendd] = size(xd);
pd = 0;
beta0d = ones(pd+nendd+nexg,1)*0.2;
vnamesd = [];
resD = direction_structure(D,xd,pd,y,beta0d,qvec,testsize);
prtD = direction_print(resD,vnamesd,fid);
%--------------------------------------------------------------------------

% SIZE
% -----
% This is slightly different model to the Rydberg and Shephard model. See
% 'modelling_size.pdf' for detail. 
alpha = 0.0713;     % This is the value of alpha in Rydberg and Shephard model.
% Alpha will be fixed here to avoid the numreical problems we face when
% maximising a negative Binomial likelihood. 
% I chose the value given by Rydberg and Shephard but it can be altered.

% The rest of the variables are similar to ACTIVITY and DIRECTION
% NOTE: use either lags LD or lag S, otherwise you may encounter problems.
nobs = length(S);
xs = ones(nobs,1);
LDLs = alag(LD,2);
xs =[xs LDLs];
[nobs nends] = size(xs);
ps = 0;
param0s = ones(ps+nends+nexg,1)*0.3;
vnamess = [];
resS = size_structure(S,xs,ps,y,alpha,param0s,qvec,testsize);
prtS = size_print(resS,vnamess,fid);