function Alag = alag(dat,order)
%
% PURPOSE:  Gives the matrix of order-lagged values of dat
%--------------------------------------------------------------------------
% USAGE:    Alag = alag(dat,order)
%    where: dat = (nobs x1) vector of data.
%           order = (scalar) the lag up to which the output matrix is
%                   calculated
%--------------------------------------------------------------------------
% RETURNS:  Alag = (nobs x order) a matrix. Column i of this matrix
%               corresponds to the i-th lag of data.
%--------------------------------------------------------------------------
% NOTES:    All initial conditions are set to zero.                            
%--------------------------------------------------------------------------
% OTHER FUNCTIONS USED HERE: --
%--------------------------------------------------------------------------

% Written by Ziad Daoud: z.daoud@lse.ac.uk
% Last updated 19/08/2008


nobs = length(dat);

Alag = ones(nobs,order)*-99;
index = 1;
while index < (order+1)
    A_minus_index = [zeros(index,1) ; dat(1:nobs-index)];
    %initial conditions are set to zero
    Alag(:,index) = A_minus_index;
    index = index+1;
end
