function [lags , boxpie , crval] = boxpierce(resid,qvec,alpha)
%
% PURPOSE:  Calculates the Box-Pierce statistics.
%--------------------------------------------------------------------------
% USAGE:    bp = boxpierce(resid,qvec,alpha)
%    where: resid = (nobs x1) vector of residuals.
%           qvec  = (nq x 1) vector of lags for which the Box-Pierce statistics
%                   is calculated.
%                   The elements of qvec must be ordered in an ascending
%                   order.
%           alpha = (scalar) size of the test
%--------------------------------------------------------------------------
% RETURNS:  lags = (nq x1) vector of lags at which BP is calculated. It is
%                  exactly qvec.
%            boxpie = (nq x1) vector of the BP stat. Each element corresponds 
%                   to the lag given by qvec.
%            crval  =  (nq x1) critical values of chi-sqare with degrees of 
%                   freedom equal to the correpoding element in qvec. 
%--------------------------------------------------------------------------
% NOTES:    The elements of qvec must be ordered in an ascending order.                             
%--------------------------------------------------------------------------
% OTHER FUNCTIONS USED HERE: acf
%--------------------------------------------------------------------------

% Written by Ziad Daoud: z.daoud@lse.ac.uk
% Last updated 19/08/2008

nq = length(qvec);

% error checking
index = 1;
while index < nq
    if qvec(index) > qvec(index+1)
        error('The elements of qvec must be in an ascending order in boxpierce');
    else
        index = index+1;
    end
end


lags = qvec;
crval = chi2inv(1-alpha, lags);

T = length(resid);
qmax = max(qvec);

boxpiemat = zeros(qmax, nq);

qvecnew = [0; qvec];

index2 = 1;
while index2 < nq+1
    index1 = qvecnew(index2) + 1;
    while index1 < qvec(index2)+1
        r = acf(resid,index1);
        r2 = ones(1 , nq-index2+1)*(r^2);
        boxpiemat(index1 , index2:nq) = r2;
        index1 = index1 +1;
    end
    index2= index2+1;
end

bp = sum(boxpiemat); 
% sum(A) treats the columns of A as vectors, returning a row vector of the 
% sums of each column. 
boxpie = T * bp';
